#ifndef THERMISTOR_h
#define THERMISTOR_H

#include "Arduino.h"

#define THERMISTOR_BETA 0
#define THERMISTOR_STEINHART 1

#define THERMISTOR_ORIENTATION 1			  // (0 = Thermistor on LOW/GND side of Voltage Divider Circuit, 1 = HIGH/VCC side)

/*
https://www.thinksrs.com/downloads/programs/therm%20calc/ntccalibrator/ntccalculator.html

*** 100K Thermopro Thermistor (TP20...): Amazon https://www.amazon.com/gp/product/B07W2YYB14 
t1 = 0c   = 322.2 KOhm
t2 = 21c  = 110.4 KOhm
t3 = 100c =   7.1 KOhm
TNOMINAL 25                 // Temp for nominal resistance (almost always 25 C)
RNOMINAL 97658.94           // Resistance at Nominal Temp
BETA 3888.55                // Beta coefficient of the thermistor (usually 3000-4000)  3950?
SHC1 0.04939322645e-03      // Steinhart-Hart Coefficient 1
SHC2 3.079879022e-04        // Steinhart-Hart Coefficient 2
SHC3 -1.443971343e-07       // Steinhart-Hart Coefficient 3


*** 100K FireBoard NTC Thermistor
TNOMINAL 25                 // Temp for nominal resistance (almost always 25 C)
RNOMINAL 96991.45           // Resistance at Nominal Temp
BETA 3878.38                // Beta coefficient of the thermistor (usually 3000-4000)  3950?
SHC1 0.06030745106e-03      // Steinhart-Hart Coefficient 1
SHC2 3.062224756e-04        // Steinhart-Hart Coefficient 2
SHC3 -1.375981548e-07       // Steinhart-Hart Coefficient 3

*** 1M PR-002 ET-732/733/905 Thermistor: Amazon https://www.amazon.com/gp/product/B006XLWL7K
TNOMINAL 25                 // Temp for nominal resistance (almost always 25 C)
RNOMINAL 948873.61          // Resistance at Nominal Temp
BETA 4489.70                // Beta coefficient of the thermistor (usually 3000-4000)  3950?
SHC1 0.2567744399e-03       // Steinhart-Hart Coefficient 1
SHC2 2.265620358e-04        // Steinhart-Hart Coefficient 2
SHC3 -0.075525075e-07       // Steinhart-Hart Coefficient 3

*/

class THERMISTOR
{
  public:
    THERMISTOR(uint8_t InputPin, uint8_t PwrPin, uint8_t Type, float P1, float P2, float P3, int VDivRes, uint8_t ResBits, uint8_t Samples=10, int ESP32ADC=1, float VSource=3.3);
		float GetTemp(float *TempF=NULL, float *TempC=NULL, char *StringF=NULL, char *StringC=NULL, int *R=NULL, int *ADC=NULL, float *Volts=NULL);
		float CorrectESP32ADC(float ADCin);
	private:
		uint8_t TM_PIN_INPUT;			// Input Pin
		uint8_t TM_PIN_PWR;				// Power Pin
		uint8_t TM_TYPE;					// Thermistor Definition Type: 0=Beta, 1=Steinhart

		float   TM_TNOMINAL;  		// Temp for nominal resistance (almost always 25 C)
		float   TM_RNOMINAL;   		// Resistance at Nominal Temp
		float   TM_BETA;         	// Beta coefficient of the thermistor (usually 3000-4000)  3950?

		float   TM_SHC1;       		// Steinhart-Hart Coefficient 1
		float   TM_SHC2;        	// Steinhart-Hart Coefficient 2
		float   TM_SHC3;       		// Steinhart-Hart Coefficient 3

		int     TM_VDIVRES;      	// Voltage Divider Reference Resistance (Ohms)
		uint8_t TM_RESBITS;      	// Analog Input Resolution (Bits)
		int     TM_STEPS;					// Number of Steps in ADC Resolution (2^TM_RESBITS)
		uint8_t TM_SAMPLES;      	// Number of Samples
		
		int     TM_ESP32ADC;      // Apply Correction for non-linear ESP32 ADC (0=No, 1=Yes)
		float   TM_VSOURCE;				// Voltage Divider Source Voltags (only required if TM_VOLTS is required);

		float   TM_ADC;						// Calculated ADC
		float   TM_VOLTS;					// Calculated Volts
		float   TM_RES;						// Calculated Resistance
		float   TM_TK;						// Calculated Temp Kelvin
		float   TM_TC;						// Calculated Temp Celsius
		float   TM_TF;						// Calculated Temp Fahrenheit
 };


#endif

